@@ -7,12 +7,13 @@ from typing import Union, Iterable, List, Dict, Set
 
 import yaml
 from dotty_dict import Dotty
-from ddb.utils.simpleeval import simple_eval
 
 from ddb.feature import features
 from ddb.feature.traefik import TraefikExtraServicesAction
+from ddb.utils.simpleeval import simple_eval
 from .binaries import DockerBinary
 from .lib.compose.config.types import ServicePort
+from .utils import DockerComposeControl
 from ...action import Action
 from ...action.action import EventBinding, InitializableAction
 from ...binary import binaries, Binary
@@ -20,7 +21,7 @@ from ...cache import caches, register_project_cache
 from ...config import config
 from ...context import context
 from ...event import bus, events
-from ...utils.process import run
+from ...utils.compat import posix_as_path_fast
 from ...utils.table_display import get_table_display
 
 
@@ -59,15 +60,14 @@ class EmitDockerComposeConfigAction(Action):
         if not os.path.exists("docker-compose.yml"):
             return
 
-        yaml_output = run("docker-compose", "config")
-
-        parsed_config = yaml.load(yaml_output, yaml.SafeLoader)
-        docker_compose_config = Dotty(parsed_config)
+        control = DockerComposeControl()
+        yaml_output = control.config(parse=False)
 
         if self.current_yaml_output == yaml_output:
             return
         self.current_yaml_output = yaml_output
 
+        docker_compose_config = Dotty(yaml.load(yaml_output, yaml.SafeLoader))
         events.docker.docker_compose_config(docker_compose_config=docker_compose_config)
 
         services = docker_compose_config.get('services')
@@ -332,13 +332,19 @@ class LocalVolumesAction(Action):
                                       relative_path)
 
     @staticmethod
-    def _check_file_in_project(target):
-        target_path = os.path.realpath(target)
+    def _check_file_in_project(source):
+        if os.name == 'nt':
+            source = posix_as_path_fast(source)
+
+        target_path = os.path.realpath(source)
         cwd = os.path.realpath(".")
         return target_path.startswith(cwd)
 
     @staticmethod
     def _create_local_volume(source, target):
+        if os.name == 'nt':
+            source = posix_as_path_fast(source)
+
         rel_source = os.path.relpath(source, ".")
         if os.path.exists(source):
             context.log.notice("Local volume source: %s (exists)", rel_source)
@@ -393,7 +399,7 @@ class LocalVolumesAction(Action):
                     source = PurePosixPath(device).joinpath(volume)
                     target = external_volumes_dict.get(volume)
                     if source and target:
-                        volume_mapping = (source, target)
+                        volume_mapping = (str(source), target)
                         if volume_mapping not in volume_mappings:
                             volume_mappings.append(volume_mapping)
 
@@ -426,15 +432,14 @@ class DockerDisplayInfoAction(Action):
         if not os.path.exists("docker-compose.yml"):
             return
 
-        yaml_output = run("docker-compose", "config")
-
-        parsed_config = yaml.load(yaml_output, yaml.SafeLoader)
-        docker_compose_config = Dotty(parsed_config)
+        control = DockerComposeControl()
+        yaml_output = control.config(parse=False)
 
         if self.current_yaml_output == yaml_output:
             return
         self.current_yaml_output = yaml_output
 
+        docker_compose_config = Dotty(yaml.load(yaml_output, yaml.SafeLoader))
         services = docker_compose_config.get('services')
         if not services:
             return
@@ -471,7 +476,7 @@ class DockerDisplayInfoAction(Action):
         return environments
 
     @staticmethod
-    def _retrieve_service_ports(service_config: Dotty) -> List[ServicePort]:  # pylint: disable=no-self-use
+    def _retrieve_service_ports(service_config: Dotty) -> List[ServicePort]:
         """
         Retrieve services ports data
         :param service_config: the service configuration
@@ -497,7 +502,7 @@ class DockerDisplayInfoAction(Action):
         return service_ports
 
     @staticmethod
-    def _retrieve_binaries_data(service_config: Dotty) -> List[str]:  # pylint: disable=no-self-use
+    def _retrieve_binaries_data(service_config: Dotty) -> List[str]:
         """
         Retrieve binaries data
         :param service_config: the service configuration
@@ -522,7 +527,7 @@ class DockerDisplayInfoAction(Action):
         return binaries_labels
 
     @staticmethod
-    def _retrieve_vhosts_data(service_config: Dotty) -> List[str]:  # pylint: disable=no-self-use
+    def _retrieve_vhosts_data(service_config: Dotty) -> List[str]:
         """
         Retrieve vhosts data
         :param service_config: the service configuration
@@ -557,7 +562,7 @@ class DockerDisplayInfoAction(Action):
         return vhosts_labels
 
     @staticmethod
-    def _output_data(service_name: str, environments: Dict[str, str],  # pylint: disable=no-self-use
+    def _output_data(service_name: str, environments: Dict[str, str],
                      ports: List[ServicePort], docker_binaries: List[str], vhosts: List[str]):
         """
         Process the data and render it to the user
