@@ -8,4 +8,4 @@ class GitSchema(FeatureSchema):
     """
     Git schema.
     """
-    fix_files_permissions = fields.Bool(default=True)
+    fix_files_permissions = fields.Bool(dump_default=True)
