@@ -2,8 +2,14 @@
 from marshmallow import Schema, fields
 
 
-class FeatureSchema(Schema):
+class DisableableSchema(Schema):
+    """
+    Base feature schema.
+    """
+    disabled = fields.Bool(dump_default=False)
+
+
+class FeatureSchema(DisableableSchema):
     """
     Base feature schema.
     """
-    disabled = fields.Bool(default=False)
