@@ -27,8 +27,8 @@ class PathSchema(Schema):
     """
     Shell schema.
     """
-    directories = fields.List(fields.String(), required=False, default=_get_path_default)
-    prepend = fields.Boolean(default=True)
+    directories = fields.List(fields.String(), required=False, dump_default=_get_path_default)
+    prepend = fields.Boolean(dump_default=True)
 
 
 class ShellSchema(FeatureSchema):
@@ -36,9 +36,9 @@ class ShellSchema(FeatureSchema):
     Shell schema.
     """
     shell = fields.String(required=True)
-    path = fields.Nested(PathSchema, required=True, default=PathSchema())
-    envignore = fields.List(fields.String(), required=False, default=[
+    path = fields.Nested(PathSchema, required=True, dump_default=PathSchema())
+    envignore = fields.List(fields.String(), required=False, dump_default=[
         "PYENV_*", "_", "PS1", "PS2", "PS3", "PS4", "PWD"
     ])
-    aliases = fields.Dict(required=False, default={})
-    global_aliases = fields.List(fields.String(), required=False, default=[])
+    aliases = fields.Dict(required=False, dump_default={})
+    global_aliases = fields.List(fields.String(), required=False, dump_default=[])
