@@ -24,7 +24,7 @@ class TestHasSameContent:
 
 class TestFileWalker:
     def test_should_exclude_files_in_excluded_directory(self):
-        fw = FileWalker([], ["**/node_modules"], [], ".")
+        fw = FileWalker([], ["**/node_modules"], [], [], [], ".")
         assert fw.is_source_filtered("blabla/node_modules") is True
         assert fw.is_source_filtered("blabla/node_modules/file") is True
         assert fw.is_source_filtered("blabla/node_modules/subdirectory/file") is True
